==> nextcloud-25.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/viewer/l10n/de_DE.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Betrachter",
    "Simple file viewer with slideshow for media" : "Einfacher Datei-Betrachter mit Diashow für Medien",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Zeigen Sie Ihre letzten Urlaubsfotos und -videos wie im Film, geben Sie einen Einblick in Ihren neuesten Roman direkt aus Ihrer Nextcloud, wählen Sie die besten GIF-Dateien aus Ihrer Sammlung dank der direkten Vorschau Ihrer favorisierten Dateien und viel mehr!",
    "Your browser does not support audio." : "Ihr Browser unterstützt kein Audio.",
    "Error loading {name}" : "Fehler beim Laden von {name}",
    "Image saved" : "Bild gespeichert",
    "Unsaved changes" : "Ungespeicherte Änderungen",
    "Drop changes" : "Änderungen verwerfen",
    "Your browser does not support videos." : "Ihr Browser unterstützt keine Videos.",
    "Edit" : "Bearbeiten",
    "Open sidebar" : "Seitenleiste öffnen",
    "Download" : "Herunterladen",
    "Delete" : "Löschen",
    "There is no plugin available to display this file type" : "Es ist kein Plugin zum Anzeigen dieses Dateityps verfügbar",
    "View" : "Ansicht",
    "Name" : "Name",
    "Save" : "Speichern",
    "Save as" : "Speichern als",
    "Back" : "Zurück",
    "Loading …" : "Lade …",
    "Reset" : "Zurücksetzen",
    "All changes will be lost." : "Alle Änderungen gehen verloren.",
    "Are you sure you want to continue?" : "Sind Sie sich sicher, dass Sie fortsetzen wollen?",
    "Cancel" : "Abbrechen",
    "Continue" : "Fortsetzen",
    "Undo" : "Rückgängig",
    "Redo" : "Wiederherstellen",
    "Show original image" : "Originalbild anzeigen",
    "Zoom in" : "Hineinzoomen",
    "Zoom out" : "Hinauszoomen",
    "Toggle zoom menu" : "Zoom-Menü umschalten",
    "Adjust" : "Anpassen",
    "Fine-tune" : "Feinabstimmung",
    "Filters" : "Filter",
    "Watermark" : "Wasserzeichen",
    "Draw" : "Zeichnen",
    "Resize" : "Größe ändern",
    "Invalid image." : "Ungültiges Bild.",
    "Error while uploading the image." : "Fehler beim Hochladen des Bildes.",
    "are not images" : "Sind keine Bilder",
    "is not an image" : "Ist kein Bild",
    "to be uploaded" : "zum Hochladen",
    "Crop" : "Zuschneiden",
    "Original" : "Original",
    "Custom" : "Benutzerdefiniert",
    "Square" : "Quadrat",
    "Landscape" : "Landschaft",
    "Portrait" : "Porträt",
    "Ellipse" : "Ellipse",
    "Classic TV" : "Klassisches Fernsehen",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Pfeil",
    "Blur" : "Verwischen",
    "Brightness" : "Helligkeit",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Spiegeln X rückgängig",
    "Flip X" : "Spiegeln X",
    "Un-flip Y" : "Spiegeln Y rückgängig",
    "Flip Y" : "Spiegeln Y",
    "HSV" : "HSV",
    "Hue" : "Farbton",
    "Saturation" : "Sättigung",
    "Value" : "Wert",
    "Image" : "Bild",
    "Importing …" : "Importiere…",
    "+ Add image" : "+ Bild hinzufügen",
    "Line" : "Linie",
    "Pen" : "Stift",
    "Polygon" : "Polygon",
    "Sides" : "Seiten",
    "Rectangle" : "Rechteck",
    "Corner Radius" : "Eckenradius",
    "Width in pixels" : "Breite in Pixel",
    "Height in pixels" : "Höhe in Pixel",
    "Toggle ratio lock" : "Verhältnis-Sperre umschalten",
    "Reset to original image size" : "Auf ursprüngliche Bildgröße zurücksetzen",
    "Rotate" : "Rotieren",
    "Text" : "Text",
    "Text spacing" : "Text-Abstand",
    "Text alignment" : "Textausrichtung",
    "Font family" : "Schriftenfamilie",
    "Size" : "Größe",
    "Letter spacing" : "Buchstaben-Abstand",
    "Line height" : "Zeilenhöhe",
    "Warmth" : "Wärme",
    "+ Add watermark" : "+ Wasserzeichen hinzufügen",
    "Choose watermark type" : "Wasserzeichentyp auswählen",
    "Upload watermark" : "Wasserzeichen hochladen",
    "Add as text" : "Als Text hinzufügen",
    "Padding" : "Auffüllen",
    "Shadow" : "Schatten",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertikal",
    "Opacity" : "Deckkraft",
    "Position" : "Position",
    "Stroke" : " Strich",
    "Save image as" : "Bild speichern als",
    "Extension" : "Erweiterung",
    "Name is required." : "Name ist erforderlich.",
    "Quality" : "Qualität",
    "Saved image size (width x height)" : "Gespeicherte Bildgröße (Breite x Höhe)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Beachten Sie, dass der ausgewählte Zuschneidebereich kleiner ist als die angewendete Größenänderung, was zu Qualitätseinbußen führen kann",
    "Actual size (100%)" : "Tatsächliche Größe (100%)",
    "Fit size" : "Größe anpassen",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Zeigen Sie Ihre letzten Urlaubsfotos und -videos wie im Film, geben Sie einen Einblick in Ihren neuesten Roman direkt aus Ihrer Nextcloud, wählen Sie die besten GIF-Dateien aus Ihrer Sammlung dank der direkten Vorschau Ihrer favorisierten Dateien und viel mehr!"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/viewer/l10n/de_DE.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Betrachter",
    "Simple file viewer with slideshow for media" : "Einfacher Datei-Betrachter mit Diashow für Medien",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Zeigen Sie Ihre letzten Urlaubsfotos und -videos wie im Film, geben Sie einen Einblick in Ihren neuesten Roman direkt aus Ihrer Nextcloud, wählen Sie die besten GIF-Dateien aus Ihrer Sammlung dank der direkten Vorschau Ihrer favorisierten Dateien und viel mehr!",
    "Your browser does not support audio." : "Ihr Browser unterstützt kein Audio.",
    "Error loading {name}" : "Fehler beim Laden von {name}",
    "You are about to overwrite the original file. Are you sure you want to continue?" : "Sie sind im Begriff, die Originaldatei zu überschreiben. Möchten Sie fortfahren?",
    "A file with this name already exists. Do you want to overwrite it?" : "Eine Datei mit diesem Namen existiert bereits. Soll diese wirklich überschrieben werden?",
    "Confirm overwrite" : "Überschreiben bestätigen",
    "Cancel" : "Abbrechen",
    "Overwrite" : "Überschreiben",
    "An error occurred while trying to confirm the file overwrite." : "Es ist ein Fehler beim Versuch, das Überschreiben der Datei zu bestätigen, aufgetreten.",
    "Image saved" : "Bild gespeichert",
    "Error saving image" : "Fehler beim Speichern des Bildes",
    "Play the live photo" : "Live-Foto abspielen",
    "LIVE" : "LIVE",
    "Your browser does not support videos." : "Ihr Browser unterstützt keine Videos.",
    "This file no longer exists" : "Diese Datei existiert nicht mehr",
    "There is no plugin available to display this file type" : "Es ist kein Plugin zum Anzeigen dieses Dateityps verfügbar",
    "Failed to save file before download" : "Datei konnte vor dem Herunterladen nicht gespeichert werden",
    "Edit" : "Bearbeiten",
    "Exit full screen" : "Vollbild verlassen",
    "Full screen" : "Vollbild",
    "Open sidebar" : "Seitenleiste öffnen",
    "Download" : "Herunterladen",
    "Delete" : "Löschen",
    "View" : "Ansicht",
    "Name" : "Name",
    "Save" : "Speichern",
    "Save as" : "Speichern als",
    "Back" : "Zurück",
    "Loading …" : "Lade …",
    "Reset" : "Zurücksetzen",
    "All changes will be lost." : "Alle Änderungen gehen verloren.",
    "Are you sure you want to continue?" : "Sind Sie sich sicher, dass Sie fortsetzen wollen?",
    "Apply" : "Anwenden",
    "Warning" : "Warnung",
    "Confirm" : "Bestätigen",
    "Discard changes" : "Änderungen verwerfen",
    "Undo" : "Rückgängig",
    "Redo" : "Wiederherstellen",
    "Show original image" : "Originalbild anzeigen",
    "Zoom in" : "Hineinzoomen",
    "Zoom out" : "Hinauszoomen",
    "Toggle zoom menu" : "Zoom-Menü umschalten",
    "Adjust" : "Anpassen",
    "Fine-tune" : "Feinabstimmung",
    "Filters" : "Filter",
    "Watermark" : "Wasserzeichen",
    "Draw" : "Zeichnen",
    "Resize" : "Größe ändern",
    "Image name" : "BIldname",
    "Invalid image." : "Ungültiges Bild.",
    "Error while uploading the image." : "Fehler beim Hochladen des Bildes.",
    "are not images" : "Sind keine Bilder",
    "is not an image" : "Ist kein Bild",
    "to be uploaded" : "zum Hochladen",
    "Crop" : "Zuschneiden",
    "Original" : "Original",
    "Custom" : "Benutzerdefiniert",
    "Square" : "Quadrat",
    "Landscape" : "Landschaft",
    "Portrait" : "Porträt",
    "Ellipse" : "Ellipse",
    "Classic TV" : "Klassisches Fernsehen",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Pfeil",
    "Blur" : "Verwischen",
    "Brightness" : "Helligkeit",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Spiegeln X rückgängig",
    "Flip X" : "Spiegeln X",
    "Un-flip Y" : "Spiegeln Y rückgängig",
    "Flip Y" : "Spiegeln Y",
    "HSV" : "HSV",
    "Hue" : "Farbton",
    "Saturation" : "Sättigung",
    "Value" : "Wert",
    "Image" : "Bild",
    "Importing …" : "Importiere…",
    "+ Add image" : "+ Bild hinzufügen",
    "Upload image" : "Bild hochladen",
    "From gallery" : "Von der Galerie",
    "Line" : "Linie",
    "Pen" : "Stift",
    "Polygon" : "Polygon",
    "Sides" : "Seiten",
    "Rectangle" : "Rechteck",
    "Corner Radius" : "Eckenradius",
    "Width in pixels" : "Breite in Pixel",
    "Height in pixels" : "Höhe in Pixel",
    "Toggle ratio lock" : "Verhältnis-Sperre umschalten",
    "Reset to original image size" : "Auf ursprüngliche Bildgröße zurücksetzen",
    "Rotate" : "Rotieren",
    "Text" : "Text",
    "Text spacing" : "Text-Abstand",
    "Text alignment" : "Textausrichtung",
    "Font family" : "Schriftenfamilie",
    "Size" : "Größe",
    "Letter spacing" : "Buchstaben-Abstand",
    "Line height" : "Zeilenhöhe",
    "Warmth" : "Wärme",
    "+ Add watermark" : "+ Wasserzeichen hinzufügen",
    "+ Add text watermark" : "+ Text-Wasserzeichen hinzufügen",
    "Choose watermark type" : "Wasserzeichentyp auswählen",
    "Upload watermark" : "Wasserzeichen hochladen",
    "Add as text" : "Als Text hinzufügen",
    "Padding" : "Auffüllen",
    "Paddings" : "Auffüllungen",
    "Shadow" : "Schatten",
    "Horizontal" : "Horizontal",
    "Vertical" : "Vertikal",
    "Opacity" : "Deckkraft",
    "Transparency" : "Transparenz",
    "Position" : "Position",
    "Stroke" : " Strich",
    "Save image as" : "Bild speichern als",
    "Extension" : "Erweiterung",
    "Format" : "Format",
    "Name is required." : "Name ist erforderlich.",
    "Quality" : "Qualität",
    "Saved image size (width x height)" : "Gespeicherte Bildgröße (Breite x Höhe)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Beachten Sie, dass der ausgewählte Zuschneidebereich kleiner ist als die angewendete Größenänderung, was zu Qualitätseinbußen führen kann",
    "Actual size (100%)" : "Tatsächliche Größe (100%)",
    "Fit size" : "Größe anpassen",
    "Select image to add …" : "Bild zum Hinzufügen auswählen …",
    "Failed to load image." : "Bild konnte nicht geladen werden",
    "Menu" : "Menü",
    "Width" : "Breite",
    "Height" : "Höhe",
    "No preview available for this crop item" : "Für diesen Zuschnitt ist keine Vorschau verfügbar"
},
"nplurals=2; plural=(n != 1);");
